pub struct DomainRateLimiter { /* private fields */ }Expand description
Per-domain rate limiter to ensure respectful crawling
Implementations
Sourceimpl DomainRateLimiter
impl DomainRateLimiter
Sourcepub fn new(requests_per_second: u32) -> Self
pub fn new(requests_per_second: u32) -> Self
Create a new rate limiter with a default requests-per-second limit
Sourcepub async fn wait_for_permission(&self, url: &str) -> Result<(), String>
pub async fn wait_for_permission(&self, url: &str) -> Result<(), String>
Wait until we’re allowed to make a request to this domain
Sourcepub fn set_domain_rate(&self, domain: &str, requests_per_second: u32)
pub fn set_domain_rate(&self, domain: &str, requests_per_second: u32)
Set custom rate for specific domain