BrowserGuard

Struct BrowserGuard 

pub struct BrowserGuard { /* private fields */ }
Guard that returns browser to pool when dropped

Methods from Deref<Target = Browser>

pub fn websocket_address(&self) -> &String

Returns the address of the websocket this browser is attached to

pub fn is_incognito(&self) -> bool

Whether the BrowserContext is incognito.

pub fn config(&self) -> Option<&BrowserConfig>

The config of the spawned chromium instance if any.

pub async fn new_page( &self, params: impl Into<CreateTargetParams>, ) -> Result<Page, CdpError>

Create a new browser page

pub async fn version(&self) -> Result<GetVersionReturns, CdpError>

Version information about the browser

pub async fn user_agent(&self) -> Result<String, CdpError>

Returns the user agent of the browser

pub async fn execute<T>( &self, cmd: T, ) -> Result<CommandResponse<<T as Command>::Response>, CdpError>
where T: Command,

Call a browser method.

pub async fn pages(&self) -> Result<Vec<Page>, CdpError>

Return all of the pages of the browser

pub async fn get_page(&self, target_id: TargetId) -> Result<Page, CdpError>

Return page of given target_id

pub async fn event_listener<T>(&self) -> Result<EventStream<T>, CdpError>
where T: IntoEventKind,

Set listener for browser event

pub async fn create_browser_context( &self, params: CreateBrowserContextParams, ) -> Result<BrowserContextId, CdpError>

Creates a new empty browser context.

pub async fn dispose_browser_context( &self, browser_context_id: impl Into<BrowserContextId>, ) -> Result<(), CdpError>

Deletes a browser context.

pub async fn clear_cookies(&self) -> Result<(), CdpError>

Clears cookies.

pub async fn get_cookies(&self) -> Result<Vec<Cookie>, CdpError>

Returns all browser cookies.

pub async fn set_cookies( &self, cookies: Vec<CookieParam>, ) -> Result<&Browser, CdpError>

Sets given cookies.