EditChannelPositionPayload

Struct EditChannelPositionPayload 

pub struct EditChannelPositionPayload {
    pub id: u64,
    pub position: u16,
    pub parent_id: Maybe<u64>,
}
The payload used per channel to specify its new position data.

Fields

id: u64

The ID of the channel to modify.

position: u16

The new position of the channel.

parent_id: Maybe<u64>

The new parent category of the channel. If left blank, the scope will not be changed. If set to Null, the channel will be moved to the root of the channel list.