pub struct DeleteGuildPayload {
pub password: String,
}Expand description
The payload sent to delete a guild.
Fields
password: StringThe password of the user. If this is a bot account, the password is not required and no body should be sent.