Member

Struct Member 

pub struct Member {
    pub user: MaybePartialUser,
    pub guild_id: u64,
    pub nick: Option<String>,
    pub roles: Option<Vec<u64>>,
    pub joined_at: DateTime<Utc>,
    pub permissions: Permissions,
}
Represents a member of a guild. Members are user objects associated with a guild.

Fields

user: MaybePartialUser

The user associated with this member. This could be None in some cases.

guild_id: u64

The ID of the guild this member is in.

nick: Option<String>

The nickname of the member. None if the member has no nickname.

roles: Option<Vec<u64>>

A list of IDs of the roles that the member has. This could be None in some cases.

joined_at: DateTime<Utc>

The time that the member joined the guild.

permissions: Permissions

The base permissions granted to the member.

Implementations

Source

impl Member

pub const fn user_id(&self) -> u64

The ID of the user associated with this member.

pub fn display_name(&self) -> Option<&str>

The display name of the member. This is the nickname if the member has one, else the username.

If the user information is not available, this will return None.