Skip to main contentModule image_processing
Source - parse_srcset_pick_largest
- Parse a srcset attribute and return the largest image
Example: “small.jpg 300w, medium.jpg 600w, large.jpg 1200w” -> “large.jpg”
- rescue_noscript_images
- Rescue
tags from - resolve_lazy_images
- Resolve lazy-loaded images by promoting data-src, data-lazy-src, etc. to src.
- resolve_picture_elements
- Resolve elements to simple
tags by picking the largest . - resolve_srcsets
- Resolve all srcset attributes in HTML to use largest image
- resolve_video_posters
- Extract video poster frames as images so they appear in markdown output.